MCULE_URL = "https://mcule.s3.amazonaws.com/database/mcule_purchasable_building_blocks_210714.smi.gz"
SIGMA_URL = 'http://files.docking.org/catalogs/source/sialbb.src.txt'
MOLPORT_URL = 'http://files.docking.org/catalogs/source/molportbb.src.txt'
ZINC_IN_STOCK_URL = 'http://files.docking.org/bb/current/In-Stock.txt'
APOLLO_BB_URL = "http://files.docking.org/catalogs/source/apollobb.src.txt"
FLUROCHEM_URL = "http://files.docking.org/catalogs/source/fluorochem.src.txt"
ALFA_URL = "http://files.docking.org/catalogs/source/alfa.src.txt" # https://www.alfa.com/en/catalog/H50684/
LIFECHEM_URL = "https://www.dropbox.com/s/d0hudapz6q12eas/LC_Stock_Building_Blocks.sdf?dl=1" #


VENDORS = ['mcule', 'sigma', 'molport', 'zinc', 'apollo', 'flurochem', 'alfa', 'lifechem']

